@@ -45,6 +45,8 @@ hamzafv = {
    {a="''([Uu])", b="ؤؤ%1"},
    {a="''([Aa])", b="أأ%1"},
    {a="''([Ii])", b="ئئ%1"},
+   -- inseparable adverbial particle 'a- + 'a
+   {a="\'(a)%-\'(a)", b="أ%1اأ%2"},
    -- initial long u and i (for a, see below)
    {a="%'%_U", b="أU"},
    {a="%'%_I", b="إI"},
@@ -53,14 +55,14 @@ hamzafv = {
    {a="'i'([^uaiUAI])", b="إI%1"},   
    -- madda (historic writing below)
    {a="'a'([^uaiUAI])", b="آ%1"},
-   {a="([^uiUI])\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="%1آ%2"},
-   {a="^\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="آ%1"},
-   {a="(%W)\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="%1آ%2"},
+   {a="([^uiUI])\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="%1آ%2"},
+   {a="^\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="آ%1"},
+   {a="(%W)\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="%1آ%2"},
    {a="(A)(')(uN?)$", b="aآء%3"},
    {a="(A)(')(uN?)(%W)", b="aآء%3%4"},
    {a="(A)(')(iN?)$", b="aآء%3"},
    {a="(A)(')(iN?)(%W)", b="aآء%3%4"},
-   {a="(A)(')(i)", b="aآئ%3"}, -- historic madda
+   {a="(A)(')([iI])", b="aآئ%3"}, -- historic madda
    {a="(A)(')(u)", b="aآؤ%3"}, -- historic madda
    {a="(A)(')", b="aآء"}, -- historic madda
    -- initial (needs both ^ and %W patterns)
@@ -141,6 +143,8 @@ hamzafveasy = { -- differences marked below with 'easy'
    {a="''([Uu])", b="ؤؤ%1"},
    {a="''([Aa])", b="أأ%1"},
    {a="''([Ii])", b="ئئ%1"},
+   -- inseparable adverbial particle 'a- + 'a
+   {a="\'(a)%-\'(a)", b="أ%1اأ%2"},
    -- initial long u and i (for a, see below)
    {a="%'%_U", b="أU"},
    {a="%'%_I", b="إI"},
@@ -149,15 +153,15 @@ hamzafveasy = { -- differences marked below with 'easy'
    {a="'i'([^uaiUAI])", b="إI%1"},   
    -- madda (historic writing below)
    {a="'a'([^uaiUAI])", b="آ%1"},
-   {a="([^uiUI])\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="%1آ%2"},
-   {a="^\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="آ%1"},
-   {a="(%W)\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="%1آ%2"},
+   {a="([^uiUI])\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="%1آ%2"},
+   {a="^\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="آ%1"},
+   {a="(%W)\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="%1آ%2"},
    --easy (begin)
    {a="(A)(')(uN?)$", b="aاء%3"},
    {a="(A)(')(uN?)(%W)", b="aاء%3%4"},
    {a="(A)(')(iN?)$", b="aاء%3"},
    {a="(A)(')(iN?)(%W)", b="aاء%3%4"},
-   {a="(A)(')(i)", b="aائ%3"}, -- historic madda
+   {a="(A)(')([iI])", b="aائ%3"}, -- historic madda
    {a="(A)(')(u)", b="aاؤ%3"}, -- historic madda
    {a="(A)(')", b="aاء"}, -- historic madda
    --easy (end)
@@ -464,10 +468,12 @@ digraphsfv = {
    {a="([%_%^%.]?[Bbtjghxdrzs%`fqklmnwy])([%s])", b="%1ْ%2"},
    {a="([%_%^%.]?[Bbtjghxdrzs%`fqklmnwy])([%_]?[^%_uaiUAIYًٌٍ])", b="%1ْ%2"},
    -- take out sukūn in cases of assimilation
-   {a="(n)(ْ)(%s)([روي])", b="%1%3%4"},
-   {a="(n)(ْ)(%s)([ل])", b="%1%3%4"},
-   {a="(n)(ْ)(%s)([م])", b="%1%3%4"},
-   {a="(n)(ْ)(%s)([ن])", b="%1%3%4"},
+   {a="(n)(ْ)(%s)(ر)", b="%1%3%4"},
+   {a="(n)(ْ)(%s)(و)", b="%1%3%4"},
+   {a="(n)(ْ)(%s)(ي)", b="%1%3%4"},
+   {a="(n)(ْ)(%s)(ل)", b="%1%3%4"},
+   {a="(n)(ْ)(%s)(م)", b="%1%3%4"},
+   {a="(n)(ْ)(%s)(ن)", b="%1%3%4"},
    {a="ْ\"", b="\""},
    -- sukūn end
    {a="_t", b="ث"},
@@ -497,7 +503,7 @@ digraphsfv = {
    {a="%^d", b="ڊ"}
 }
 
-digraphsfveasy = { -- see the diffenrences under 'easy' marker below
+digraphsfveasy = { -- see the differences under 'easy' marker below
    -- iʿrāb: straight double quote must be discarded
    {a="(%-)(\"?[UI]na)(%p?%s)", b="%2%3"},
    {a="(%-)(\"?[UI]na)(%p?)$", b="%2%3"},
