@@ -40,7 +40,7 @@ captr = {
    {a="b", b="B"},
    {a="t", b="T"},
    {a="ṯ", b="Ṯ"},
-   {a="ǧ", b="Ǧ"},
+   {a="ğ", b="Ğ"},
    {a="ḥ", b="Ḥ"},
    {a="ḫ", b="Ḫ"},
    {a="d", b="D"},
@@ -133,25 +133,26 @@ tanwintrdmg = {
    {a="%-?iNI", b="i\\arbup{n}"},
    -- tanwīn preceding ʾalif conjunctionis
    {a="%-?(uN)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="\\arbup{uni}%2%3"},
-   {a="%-?(aN)(_A)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="ạ\\arbup{ni}%3%4"},
-   {a="%-?(aN)(Y)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="ạ\\arbup{ni}%3%4"},
+   {a="%-?(aN)(_A)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="ạ\\arbup{ni}%3%4"},
+   {a="%-?(aN)(Y)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="ạ\\arbup{ni}%3%4"},
    {a="(T)%-?(aN)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="t\\arbup{ani}%3%4"},
    {a="([^TA])%-?(aN)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="%1\\arbup{ani}%3%4"},
    {a="%-?(iN)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="\\arbup{ini}%2%3"},
 -- tanwīn + alif without hamza and kasra (ibn)
    {a="%-?(uN)(%s)(i)", b="\\arbup{uni}%2'"},
-   {a="%-?(aN)(_A)(%s)(i)", b="ạ\\arbup{ni}%3%'"},
-   {a="%-?(aN)(Y)(%s)(i)", b="ạ\\arbup{ni}%3%'"},
+   {a="%-?(aN)(_A)(%s)(i)", b="ạ\\arbup{ni}%3%'"},
+   {a="%-?(aN)(Y)(%s)(i)", b="ạ\\arbup{ni}%3%'"},
    {a="(T)%-?(aN)(%s)(i)", b="t\\arbup{ani}%3%'"},
    {a="([^TA])%-?(aN)(%s)(i)", b="%1\\arbup{ani}%3%'"},
    {a="%-?(iN)(%s)(i)", b="\\arbup{ini}%2%'"},
    --
 -- {a="uN", b="\\arbup{un}"}, (now included in the last line of this table)
-   {a="%-?(aN)(_A)", b="ạ\\arbup{n}"},
-   {a="%-?(aN)(Y)", b="ạ\\arbup{n}"},
+   {a="%-?(\"?At)%-?([ui])N", b="\\arbup{%1%2n}"},
+   {a="%-?(aN)(_A)", b="ạ\\arbup{n}"},
+   {a="%-?(aN)(Y)", b="ạ\\arbup{n}"},
    {a="(T)%-?(\"?aN)", b="t\\arbup{an}"},
    {a="([^TA])%-?(\"?aN)", b="%1\\arbup{an}"},
-   {a="(%-?)(\"?A?t?)(%-?)([ui])(N)", b="\\arbup{%2%4n}"}
+   {a="%-?([ui])N", b="\\arbup{%1n}"}
 }
 
 trigraphstrdmg = { -- trigraphs or more
@@ -266,13 +267,19 @@ trigraphstrdmgeasy = { -- see the differences below under 'easy' tag
 
 digraphstrdmg = {
    {a="([uai]%-)(\"?[uai])", b="%1'"}, -- hyphen + initial alif without hamza
-   {a="^(\"?[uai])", b="%1"},      -- initial alif without hamza
+   -- the following two are replaced with the 4 lines next for now
+--   {a="^(\"?[uai])", b="%1"},      -- initial alif without hamza
+--   {a="(%W)(\"?[uai])", b="%1%2"},      -- initial alif without hamza
+   {a="^(\"[uai])", b="'"},      -- initial alif without hamza
+   {a="(%W)(\"[uai])", b="%1'"},      -- initial alif without hamza
+   {a="^([uai])", b="%1"},      -- initial alif without hamza
+   {a="(%W)([uai])", b="%1%2"},      -- initial alif without hamza
    -- this is not necessary, take out for now:
 -- {a="([%_]?[uaiUAIY])(%s)([uai])", b="%1%2'"}, -- initial alif without hamza
    {a="(aW)(%s)(\"?[uai])", b="awu%2%3"},
    {a="([^%_][uai])(%s)(\"?[uai])", b="%1%2'"},
-   {a="(%_A)(%s)(\"?[uai])", b="ạ%2'"},
-   {a="(Y)(%s)(\"?[uai])", b="ạ%2'"},
+   {a="(%_A)(%s)(\"?[uai])", b="ạ%2'"},
+   {a="(Y)(%s)(\"?[uai])", b="ạ%2'"},
    {a="(%_a)(%s)(\"?[uai])", b="a%2'"},
    {a="(A)(%s)(\"?[uai])", b="a%2'"},
    {a="([%_]?[Uu])(%s)(\"?[uai])", b="u%2'"},
@@ -293,17 +300,17 @@ digraphstrdmg = {
    {a="(U)(A)", b="U"},
    {a="(aW)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="awu%2%3"},
    {a="(%_a)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="a%2%3"},
-   {a="(%_A)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="ạ%2%3"},
+   {a="(%_A)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="ạ%2%3"},
    {a="(A)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="a%2%3"},
-   {a="(Y)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="ạ%2%3"},
+   {a="(Y)(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="ạ%2%3"},
    {a="([%_]?[Uu])(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="u%2%3"},
    {a="([%_]?[Ii])(%s)(['][%_%^%.]?[l'btjghxdrzs`fqkmnwy]%-)", b="i%2%3"},
    {a="%-%-", b=""},
 --   {a="T([^uai])", b="%1"},
-   {a="T(%p?%s)", b="%1"},
-   {a="T(%p?)$", b="%1"},
+   {a="T(%p?%s)", b="h%1"},
+   {a="T(%p?)$", b="h%1"},
    {a="_t", b="ṯ"},
-   {a="%^g", b="ǧ"},
+   {a="%^g", b="ğ"},
    {a="%.h", b="ḥ"},
    {a="_h", b="ḫ"},
    {a="_d", b="ḏ"},
@@ -317,7 +324,7 @@ digraphstrdmg = {
 --   {a="(U)(A)", b="ū"},
    {a="WA", b="w"},
    {a="(a)W", b="%1w"},
-   {a="_A", b="ạ̄"},
+   {a="_A", b="ạ̄"},
    {a="_u", b="ū"},
    {a="_a", b="ā"},
    {a="_i", b="ī"},
@@ -332,7 +339,7 @@ digraphstrdmg = {
 singletrdmg = {
    {a="b", b="b"},
    {a="t", b="t"},
-   {a="j", b="ǧ"},
+   {a="j", b="ğ"},
    {a="x", b="ḫ"},
    {a="d", b="d"},
    {a="r", b="r"},
@@ -357,7 +364,7 @@ longvtrdmg = {
    {a="A", b="ā"},
    {a="U", b="ū"},
    {a="I", b="ī"},
-   {a="Y", b="ạ̄"}
+   {a="Y", b="ạ̄"}
 }
 
 shortvtrdmg = {
@@ -439,12 +446,12 @@ tanwintrloc = {
    {a="%-?uNU", b="un"},
    {a="%-?aNU", b="an"},
    {a="%-?iNU", b="in"},
-   {a="%-?uN", b="un"},
---   {a="%-?(aN)(_A)", b="an"}, (now included in last line in this table)
+   {a="%-?(\"?At)%-?([ui])N", b="%1%2n"},
+   {a="%-?([ui])N", b="%1n"},
+   {a="%-?(aN)(_A)", b="an"},
    {a="%-?(aN)(Y)", b="an"},
    {a="(T)%-?(\"?aN)", b="tan"},
-   {a="([^TA])%-?(\"?aN)", b="%1an"},
-   {a="(%-?)(\"?A?t?)(%-?)([ui])(N)", b="%2%4n"},
+   {a="([^TA])%-?(\"?aN)", b="%1an"}
 }
 
 trigraphstrloc = { -- trigraphs or more
