@@ -71,6 +71,101 @@ raw = {
    {a="i", b="ِ"}
 }
 
+buckwalter = {
+   --- hard coded madda: hold it for now
+   {a="%|", b="@"},
+   {a="M", b="@"}, -- BW safe
+   {a="%_", b="--"}, -- taṭwīl
+   -- prevent any unwanted šadda from being generated
+   {a="bb", b="b|b"},
+   {a="tt", b="t|t"},
+   {a="vv", b="v|v"},
+   {a="jj", b="j|j"},
+   {a="HH", b="H|H"},
+   {a="xx", b="x|x"},
+   {a="dd", b="d|d"},
+   {a="%*%*", b="*|*"},
+   {a="VV", b="V|V"}, -- BW safe
+   {a="rr", b="r|r"},
+   {a="ss", b="s|s"},
+   {a="%$%$", b="$|$"},
+   {a="cc", b="c|c"}, -- BW safe
+   {a="SS", b="S|S"},
+   {a="DD", b="D|D"},
+   {a="TT", b="T|T"},
+   {a="ZZ", b="Z|Z"},
+   {a="EE", b="E|E"},
+   {a="gg", b="g|g"},
+   {a="ff", b="f|f"},
+   {a="qq", b="q|q"},
+   {a="kk", b="k|k"},
+   {a="ll", b="l|l"},
+   {a="mm", b="m|m"},
+   {a="nn", b="n|n"},
+   {a="hh", b="h|h"},
+   {a="ww", b="w|w"},
+   {a="yy", b="y|y"},
+   -- hamza begin
+   -- look into this later on:
+--   {a="%>a?A", b="@@@"}, -- hold this (madda)
+--   {a="%>a\'([^uai])", b="@@@%1"}, -- hold this (madda)
+   {a="a?A\'", b="@@"}, -- hold this (classic madda)
+   {a="\'", b="|\"\'"},
+   {a="C", b="|\"\'"}, -- BW safe
+   {a="%>", b="a\"\'"},
+   {a="O", b="a\"\'"}, -- BW safe
+   {a="%&", b="w\"\'"},
+   {a="W", b="w\"\'"}, -- BW safe
+   {a="%<", b="i\"\'"},
+   {a="I", b="i\"\'"}, -- BW safe
+   {a="%]", b="y\"\'"},
+   {a="Q", b="y\"\'"},
+   -- hamza end
+   -- trigraphs
+   {a="^Aal%-?", b="al-"},
+   {a="(%W)Aal%-?", b="%1al-"},
+   {a="(%s)Aal%-?", b="%1al-"},
+   {a="([%-%s])Al%-?", b="%1\'l-"},
+   {a="^A", b="a"},
+   {a="(%W)A", b="%1a"},
+   {a="(%s)A", b="%1a"},
+   {a="(al%-[%g])(%~)", b="%1"},
+   {a="(\'l%-[%g])(%~)", b="%1"},
+   -- digraphs begin
+   {a="aA", b="A"},
+   {a="uw([^%~])", b="U%1"},
+   {a="iy([^%~])", b="I%1"},
+   -- digraphs end
+   -- madda: get it back now
+--   {a="%@%@%@", b="\'A"},
+   {a="%@%@", b="A\'"}, -- give back classic madda
+   {a="%@", b="A\"\'"}, -- hard coded madda
+   -- šadda:
+   {a="([%g])(%~)", b="%1%1"},
+   {a="%`", b="_a"},
+   {a="e", b="_a"}, -- BW safe
+   {a="v", b="_t"},
+   {a="H", b=".h"},
+   {a="%*", b="_d"},
+   {a="V", b="_d"}, -- BW safe
+   {a="%$", b="^s"},
+   {a="c", b="^s"}, -- BW safe
+   {a="S", b=".s"},
+   {a="D", b=".d"},
+   {a="T", b=".t"},
+   {a="Z", b=".z"},
+   {a="E", b="`"},
+   {a="g", b=".g"},
+   {a="p", b="T"},
+   {a="N", b="uN"},
+   {a="F", b="aN"},
+   {a="K", b="iN"},
+   {a="o", b="\""},
+   -- hard-coded connective alif
+   {a="%[", b="ٱ"},
+   {a="L", b="ٱ"} -- BW safe
+}
+
 hamza = {
    -- next line for ʾiʿrāb hyphen
    {a="(')(%-)([uaiUAI])", b="%1%3"},
@@ -85,6 +180,8 @@ hamza = {
    {a="''([Uu])", b="ؤؤ%1"},
    {a="''([Aa])", b="أأ%1"},
    {a="''([Ii])", b="ئئ%1"},
+   -- inseparable adverbial particle 'a- + 'a
+   {a="\'(a)%-\'(a)", b="أ%1اأ%2"},
    -- initial long u and i (for a, see below)
    {a="%'%_U", b="أU"},
    {a="%'%_I", b="إI"},
@@ -93,14 +190,14 @@ hamza = {
    {a="'i'([^uaiUAI])", b="إI%1"},   
    -- madda (historic writing below)
    {a="'a'([^uaiUAI])", b="آ%1"},
-   {a="([^uiUI])\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="%1آ%2"},
-   {a="^\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="آ%1"},
-   {a="(%W)\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="%1آ%2"},
+   {a="([^uiUI])\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="%1آ%2"},
+   {a="^\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="آ%1"},
+   {a="(%W)\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="%1آ%2"},
    {a="(A)(')(uN?)$", b="aآء%3"},
    {a="(A)(')(uN?)(%W)", b="aآء%3%4"},
    {a="(A)(')(iN?)$", b="aآء%3"},
    {a="(A)(')(iN?)(%W)", b="aآء%3%4"},
-   {a="(A)(')(i)", b="aآئ%3"}, -- historic madda
+   {a="(A)(')([iI])", b="aآئ%3"}, -- historic madda
    {a="(A)(')(u)", b="aآؤ%3"}, -- historic madda
    {a="(A)(')", b="aآء"}, -- historic madda
    -- initial (needs both ^ and %W patterns)
@@ -172,6 +269,8 @@ hamzaeasy = { -- differences marked below with 'easy'
    {a="''([Uu])", b="ؤؤ%1"},
    {a="''([Aa])", b="أأ%1"},
    {a="''([Ii])", b="ئئ%1"},
+   -- inseparable adverbial particle 'a- + 'a
+   {a="\'(a)%-\'(a)", b="أ%1اأ%2"},
    -- initial long u and i (for a, see below)
    {a="%'%_U", b="أU"},
    {a="%'%_I", b="إI"},
@@ -180,15 +279,15 @@ hamzaeasy = { -- differences marked below with 'easy'
    {a="'i'([^uaiUAI])", b="إI%1"},   
    -- madda (historic writing below)
    {a="'a'([^uaiUAI])", b="آ%1"},
-   {a="([^uiUI])\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="%1آ%2"},
-   {a="^\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="آ%1"},
-   {a="(%W)\'a?A([%_%^%.]?[%`%'btjghdrzsfqklmnywAY])", b="%1آ%2"},
+   {a="([^uiUI])\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="%1آ%2"},
+   {a="^\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="آ%1"},
+   {a="(%W)\'a?A([%_%^%.]?[%`%'btjghxdrzsfqklmnywAY])", b="%1آ%2"},
    --easy (begin)
    {a="(A)(')(uN?)$", b="aاء%3"},
    {a="(A)(')(uN?)(%W)", b="aاء%3%4"},
    {a="(A)(')(iN?)$", b="aاء%3"},
    {a="(A)(')(iN?)(%W)", b="aاء%3%4"},
-   {a="(A)(')(i)", b="aائ%3"}, -- historic madda
+   {a="(A)(')([iI])", b="aائ%3"}, -- historic madda
    {a="(A)(')(u)", b="aاؤ%3"}, -- historic madda
    {a="(A)(')", b="aاء"}, -- historic madda
    --easy (end)
@@ -374,6 +473,8 @@ trigraphs = { -- trigraphs or more
 }
 
 trigraphseasy = { -- differences marked below with 'easy'
+   -- Allah (easy)
+   {a="l%-l_ah", b="l-ll_ah"},
    -- 'llatI / 'llad_I
    {a="^'ll(a)([%_]?[dt])", b="الّ%1%2"},
    {a="([%s%-])'ll(a)([%_]?[dt])", b="%1الّ%2%3"},
@@ -570,7 +671,15 @@ punctuation = {
    {a="%)", b="-@("},
    {a="%+%@%(", b=")"},
    {a="%-%@%(", b="("},
-   {a="%.", b="۔"},
+   {a="%<", b="+@<"},
+   {a="%>", b="-@<"},
+   {a="%+%@%<", b=">"},
+   {a="%-%@%<", b="<"},
+   {a="%[", b="+@["},
+   {a="%]", b="-@["},
+   {a="%+%@%[", b="]"},
+   {a="%-%@%[", b="["},
+   {a="%.", b="."},
    {a="([^0-9])%,", b="%1،"},
    {a="%?", b="؟"},
    {a="%;", b="؛"},
